import com.BajieSoft.HttpSrv.Logger;
import com.BajieSoft.HttpSrv.Controler;
import javax.servlet.http.HttpServletRequest;
import java.io.*;
import java.util.*;

/**
 * <p>Title: BajieServer</p>
 * <p>Description: BajieServer Project</p>
 * <p>Copyright: Copyright (c) 2003</p>
 * <p>Company: BajieSoft</p>
 * @author Gang Zhang
 * @version 0.95zx4
 *
 * This is just a example class of writting a customized logger.
 * to compile:
 *   By hand javac -classpath ..\jzHttpSrv.jar testLogger.java
 *   Let server do it: put testLogger.java in server's load path (in directory
 *                                    servlets/ or htdocs/WEB-INF/classes) and
 *                                    under server's UI menu File->Set Custom http logger,
 *                                    set logger to same name. server will compile it.
 *
 * To load:
 *   either add the line 'HTTPLOGGERCLS=testLogger' to config/jzHttpSrv.properties file
 *   or do it with UI, under menu File->Set Custom http Logger and set the class
 *  of the logger (which for this logger is testLogger.
 */

public class testLogger implements com.BajieSoft.HttpSrv.Logger {
  private java.io.PrintStream httpout; //for http requests
  private java.io.PrintStream errout;  //for error messages
  private java.io.PrintStream sltout;  //for servlet output
  private int curDay;
  public testLogger() {    
  }
  public void reinit(){
System.out.println("init logger");
    curDay=Calendar.getInstance().get(Calendar.DAY_OF_WEEK); //rotate between 7 logs
    try{
      httpout=new java.io.PrintStream(new java.io.FileOutputStream("logs/http"+curDay+".log"));
    }catch(Exception e){e.printStackTrace();}

    sltout=System.out;  //don't care about servlet messages (init and stuff), send to system.out
    try{
      errout=new java.io.PrintStream(new java.io.FileOutputStream("logs/err"+curDay+".log"));
    }catch(Exception e){e.printStackTrace();}

  }
  //simple method of rotate between days;
  private void rotate(){
    int theday=Calendar.getInstance().get(Calendar.DAY_OF_WEEK);
    if(theday!=curDay){
      close();
      reinit(); 
    }
  }
  //http requests will be send here
  public void httpMsg(HttpServletRequest req) {
    rotate();
    String method=req.getMethod();
    String url=req.getRequestURI();
    String query=req.getQueryString();
    query=query==null?"":"?"+query;
    //You might want to change getRemoteHost() to getRemoteAddr(), since addr don't have reverse address lookup and is faster
    final StringBuffer dspstr=new StringBuffer();
    dspstr.append(new java.util.Date()).append(" ").append(method).append(" ").append(req.getRemoteAddr()).append(" ").append(url).append(query);
    {
    final String ref=req.getHeader("referer");
    if(ref!=null)dspstr.append("\r\n\trf=").append(ref);
    final String ua=req.getHeader("user-agent");
    if(ua!=null)dspstr.append("\r\n\tua=").append(ua);
    }
    dspstr.append("\r\n");
    httpout.print(dspstr.toString());
    if((Controler.uiLogCTL&Controler.LOGHTTP)!=0)Controler.uiLog(dspstr.toString());
    /*  this to print out all entries.
    Enumeration enu=req.getHeaderNames();
    while(enu.hasMoreElements()){
      String header=(String)enu.nextElement();
      System.out.println("\t"+header+"\t= "+req.getHeader(header));
    }*/
    httpout.flush();  //not efficient, but needed in case you want to see
                  //each record in real time.
  }

  public void servletMsg(final String servletName,final String msg){
    String str=servletName+":"+msg;
    sltout.println(str);
    if((Controler.uiLogCTL&Controler.LOGSLT)!=0){
      Controler.uiLog(str);
      Controler.uiLog("\n");
    }
  }
  public void errMsg(final String source,final String msg,final Throwable e){
    rotate();
    StringWriter str=new StringWriter();
    PrintWriter pr=new PrintWriter(str);
    pr.println(source+":"+msg);
    e.printStackTrace(pr);
    pr.flush();
    errout.println(str.toString());
    if((Controler.uiLogCTL&Controler.LOGERR)!=0)Controler.uiLog(str.toString());
  }
  public void srvMsg(final String msg){
    System.out.println(msg);
  }

  public void flush(){
    try{
    httpout.flush();
    errout.flush();
    }catch(Exception e){e.printStackTrace();}
  }
  public void close() {
    try{
    httpout.close();
    }catch(Exception e){e.printStackTrace();}
    try{
    errout.close();
    }catch(Exception e){e.printStackTrace();}
  }

}
